<?php

namespace Drupal\wsolution\Vcr;

use VCR\Configuration;
use VCR\Util\Assertion;
use VCR\VCRException;

/**
 * Provides a HTTP middleware.
 */
class WSConfigurationVcr extends Configuration {

  /**
   * List of enabled storages.
   *
   * Format:
   * array(
   *  'name' => 'class name'
   * )
   * @dev need to be override cause parent is property is private.
   *
   * @var array<string, class-string> List of available storages
   */
  public $availableStorages = [
    'blackhole' => 'VCR\Storage\Blackhole',
    'json' => 'VCR\Storage\Json',
    'yaml' => 'VCR\Storage\Yaml',
    'ws_elastic_search' => 'Drupal\wsolution\Vcr\Storage\WSElasticSearch',
  ];

  /**
   * Enables a storage by name.
   *
   * @param string $storageName name of the storage to enable
   *
   * @throws VCRException if a invalid storage name is given
   * @dev need to be override cause parent is property is private.
   */
  public function setStorage(string $storageName): self {
    Assertion::keyExists($this->availableStorages, $storageName, "Storage '{$storageName}' not available.");
    $this->enabledStorage = $storageName;
    return $this;
  }

  /**
   * Returns the class name of the storage to use.
   *
   * Objects are created in the VCRFactory.
   *
   * @return string class name of the storage to use
   * @dev need to be override cause parent is property is private.
   */
  public function getStorage(): string {
    return $this->availableStorages[$this->enabledStorage];
  }

}
